##  Creating a Presentation
Follow these steps:
  1. On the navigation bar, choose More > Presentations.
  2. On the Presentations page, click New Presentation.
  3. Enter a name for the presentation and, optionally, a description, then click Create Presentation. You land on the intro slide of the presentation.
  4. On the intro slide, edit the title and subtitle of the presentation to provide sufficient context to viewers.
  5. To add slides to the presentation, do the following:
    1. Click the plus button in the left-side pane. Alternatively, hover over the area below the slide and click the plus icon that appears.
![Adding a Slide to a Presentation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746b1417a44101482339693ad1b2c08_LowRes.png)
Adding a Slide to a Presentation
    2. In the dialog that appears, select reports and diagrams that you want to add to the presentation, then click Add. You can add multiple reports and diagrams at once. Each of them is added as a separate slide.
**Note**
To add a report or diagram to a presentation, ensure that it's accessible to all workspace users. If a report or diagram is missing from the list, modify its permissions to either Can view or Can edit. To learn more, see [Changing Permissions for Reports and Diagrams](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275be6437a4410148a0a96eb313dc8f8__changing_permissions_for_reports_and_diagrams).
![Selecting Reports and Diagrams to Add to a Presentation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274483677a441014b348f3adaaeab14c_LowRes.png)
Selecting Reports and Diagrams to Add to a Presentation
  6. Optional: Once you’ve added slides to the presentation, you can edit their titles. By default, the report or diagram title is used as the slide title. The slide titles are not synchronized with the report and diagram titles.
  7. Optional: To provide additional context and descriptions for each report or diagram, add notes (annotations) to slides. To do that, select a slide, click Edit notes, then enter your notes in the text field that appears. To learn more, see [Adding Notes to Slides](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275be6437a4410148a0a96eb313dc8f8__adding_notes_to_slides).


The presentation is automatically saved. Now you can preview the presentation or continue editing it. You can add more slides, rearrange them, or delete unnecessary slides. For more information, see [Adding, Rearranging, and Deleting Slides](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275be6437a4410148a0a96eb313dc8f8__adding_rearranging_and_deleting_slides).
**Note**
If a report or diagram is deleted or its permissions are changed to No access, it becomes unavailable in presentations. To delete an empty slide, click Delete Slide.
